--[[

	Atlas World Events, a World of Warcraft map browser for world events
	Copyright 2011 Arith Hsu

	This file is a plugin of Atlas.

	"Atlas World Events" is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]
local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local AL = LibStub("AceLocale-3.0"):GetLocale("Atlas_WorldEvents");

local BLUE = "|cff6666ff";
local GREY = "|cff999999";
local GREN = "|cff66cc33";
local YELL = "|cffcccc00";
local _RED = "|cffcc6666";
local ORNG = "|cffcc9933";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local CYAN = "|cff008888";
local INVIS = "|c00000000";
local INDENT = "    ";
local DASH = GREY.." - ";

local myCategory = AL["World Events Maps"];

local myData = {
	Lunar_Azeroth = {
		ZoneName = { AL["Lunar Festival"].." - "..BZ["Eastern Kingdoms"] };
		{ WHIT.." 1) "..AL["Elder Hammershout"]	..DASH..BLUE..BZ["Stormwind City"]..", "..BZ["Elwynn Forest"] };
		{ GREY..INDENT..AL["(Outside the city gate.)"] };
		{ WHIT.." 2) "..AL["Elder Stormbrow"]	..DASH..GREY..BZ["Goldshire"]..", "..BZ["Elwynn Forest"] };
		{ WHIT.." 3) "..AL["Elder Skychaser"]	..DASH..GREY..BZ["Sentinel Hill"]..", "..BZ["Westfall"] };
		{ WHIT.." 4) "..AL["Elder Winterhoof"]	..DASH..GREY..BZ["Booty Bay"]..", "..BZ["The Cape of Stranglethorn"] };
		{ GREY..INDENT..AL["(On the roof of the bank)"] };
		{ WHIT.." 5) "..AL["Elder Starglade"]	..DASH..GREY..BZ["Zul'Gurub"]..", "..BZ["Northern Stranglethorn"] };
		{ GREY..INDENT..AL["(Outside the gate)"] };
		{ WHIT.." 6) "..AL["Elder Bellowrage"]	..DASH..GREY..BZ["The Dark Portal"]..", "..BZ["Blasted Lands"] };
		{ WHIT.." 7) "..AL["Elder Starsong"]	..DASH..ORNG..BZ["The Temple of Atal'Hakkar"]..", "..BZ["Swamp of Sorrows"] };
		{ WHIT.." 8) "..AL["Elder Rumblerock"]	..DASH..GREY..BZ["Dreadmaul Rock"]..", "..BZ["Burning Steppes"] };
		{ WHIT.." 9) "..AL["Elder Dawnstrider"]	..DASH..GREY..BZ["Flame Crest"]..", "..BZ["Burning Steppes"] };
		{ WHIT.."10) "..AL["Elder Stonefort"]	..DASH..ORNG..BZ["Hordemar City"]..", "..BZ["Blackrock Spire"].." ("..AL["Lower"]..")" };
		{ WHIT.."11) "..AL["Elder Morndeep"]	..DASH..ORNG..BZ["Ring of the Law"]..", "..BZ["Blackrock Depths"] };
		{ WHIT.."12) "..AL["Elder Ironband"]	..DASH..GREY..BZ["Blackchar Cave"]..", "..BZ["Searing Gorge"] };
		{ WHIT.."13) "..AL["Elder Goldwell"] 	..DASH..GREY..BZ["Kharanos"]..", "..BZ["Dun Morogh"] };
		{ WHIT.."14) "..AL["Elder Bronzebeard"]	..DASH..BLUE..BZ["The Mystic Ward"]..", "..BZ["Ironforge"]..", "..BZ["Dun Morogh"] };
		{ WHIT.."15) "..AL["Elder Silvervein"]	..DASH..GREY..BZ["Thelsamar"]..", "..BZ["Loch Modan"] };
		{ WHIT.."16) "..AL["Elder Highpeak"]	..DASH..GREY..BZ["The Creeping Ruin"]..", "..BZ["The Hinterlands"] };
		{ WHIT.."17) "..AL["Elder Snowcrown"]	..DASH..GREY..BZ["Light's Hope Chapel"]..", "..BZ["Eastern Plaguelands"] };
		{ WHIT.."18) "..AL["Elder Windrun"]	..DASH..GREY..BZ["Crown Guard Tower"]..", "..BZ["Eastern Plaguelands"] };
		{ WHIT.."19) "..AL["Elder Farwhisper"]	..DASH..ORNG..BZ["Festival Lane"]..", "..BZ["Stratholme"]..DASH..BZ["Crusaders' Square"] };
		{ WHIT.."20) "..AL["Elder Moonstrike"]	..DASH..GREY..BZ["Scholomance"]..", "..BZ["Western Plaguelands"] };
		{ GREY..INDENT..AL["(The roof of Scholomance, outside the dungeon.)"] };
		{ WHIT.."21) "..AL["Elder Meadowrun"]	..DASH..GREY..BZ["The Weeping Cave"]..", "..BZ["Western Plaguelands"] };
		{ WHIT.."22) "..AL["Elder Graveborn"]	..DASH..GREY..BZ["Brill"]..", "..BZ["Tirisfal Glades"] };
		{ WHIT.."23) "..AL["Elder Darkcore"]	..DASH..BLUE..BZ["Undercity"]..", "..BZ["Ruins of Lordaeron"]..", "..BZ["Tirisfal Glades"] };
		{ WHIT.."24) "..AL["Elder Obsidian"]	..DASH..GREY..BZ["The Sepulcher"]..", "..BZ["Silverpine Forest"] };
	};
	Lunar_Kalimdor = {
		ZoneName = { AL["Lunar Festival"].." - "..BZ["Kalimdor"] };
		{ GREN.." 1') "..AL["Valadar Starsong"]..DASH..GREY..BZ["Nighthaven"]..", "..BZ["Moonglade"] };
		{ GREN..INDENT..AL["Fariel Starsong"]..DASH..GREY..BZ["Nighthaven"]..", "..BZ["Moonglade"] };
		{ GREN.." 2') "..AL["Omen"]..DASH..AL["Southeast coast of the Lake Elune'ara"]..", "..BZ["Moonglade"] };
		{ "" };
		{ WHIT.." 1) "..AL["Elder Bladeleaf"]	..DASH..BZ["Dolanaar"]..", "..BZ["Teldrassil"] };
		{ WHIT.." 2) "..AL["Elder Bladeswift"]	..DASH..BLUE..BZ["Cenarion Enclave"]..", "..BZ["Darnassus"]..", "..BZ["Teldrassil"] };
		{ WHIT.." 3) "..AL["Elder Starweave"]	..DASH..BZ["Lor'danel"]..", "..BZ["Darkshore"] };
		{ WHIT.." 4) "..AL["Elder Riversong"]	..DASH..BZ["Astranaar"]..", "..BZ["Ashenvale"] };
		{ WHIT.." 5) "..AL["Elder Nightwind"]	..DASH..BZ["Jaedenar"]..", "..BZ["Felwood"] };
		{ WHIT.." 6) "..AL["Elder Brightspear"]	..DASH..BZ["The Ruins of Kel'Theril"]..", "..BZ["Winterspring"] };
		{ WHIT.." 7) "..AL["Elder Stonespire"]	..DASH..BZ["Everlook"]..", "..BZ["Winterspring"] };
		{ WHIT.." 8) "..AL["Elder Skygleam"]	..DASH..BZ["Ravencrest Monument"]..", "..BZ["Azshara"] };
		{ WHIT.." 9) "..AL["Elder Darkhorn"]	..DASH..BLUE..BZ["Orgrimmar"]..", "..BZ["Durotar"] };
		{ GREY..INDENT..AL["(Next to the flight master.)"] };
		{ WHIT.."10) "..AL["Runetotem the Elder"]	..DASH..BZ["Razor Hill"]..", "..BZ["Durotar"] };
		{ WHIT.."11) "..AL["Elder Windtotem"]	..DASH..BZ["Ratchet"]..", "..BZ["Northern Barrens"] };
		{ WHIT.."12) "..AL["Elder Moonwarden"]	..DASH..BZ["The Crossroads"]..", "..BZ["Northern Barrens"] };
		{ WHIT.."13) "..AL["Elder High Mountain"]	..DASH..BZ["Vendetta Point"]..", "..BZ["Southern Barrens"] };
		{ WHIT.."14) "..AL["Elder Bloodhoof"]	..DASH..BZ["Bloodhoof Village"]..", "..BZ["Mulgore"] };
		{ WHIT.."15) "..AL["Elder Ezra Wheathoof"]	..DASH..BLUE..BZ["Elder Rise"]..", "..BZ["Thunder Bluff"]..", "..BZ["Mulgore"] };
		{ WHIT.."16) "..AL["Elder Skyseer"]	..DASH..BZ["Freewind Post"]..", "..BZ["Thousand Needles"] };
		{ WHIT.."17) "..AL["Elder Morningdew"]	..DASH..BZ["Fizzle & Pozzik's Speedbarge"]..", "..BZ["Thousand Needles"] };
		{ WHIT.."18) "..AL["Elder Dreamseer"]	..DASH..BZ["Gadgetzan"]..", "..BZ["Tanaris"] };
		{ WHIT.."19) "..AL["Elder Wildmane"]	..DASH..ORNG..BZ["Zul'Farrak"]..", "..BZ["Tanaris"] };
		{ WHIT.."20) "..AL["Elder Ragetotem"]	..DASH..BZ["Valley of the Watchers"]..", "..BZ["Tanaris"] };
		{ WHIT.."21) "..AL["Elder Thunderhorn"]	..DASH..BZ["The Slithering Scar"]..", "..BZ["Un'Goro Crater"] };
		{ WHIT.."22) "..AL["Elder Bladesing"]	..DASH..BZ["Cenarion Hold"]..", "..BZ["Silithus"] };
		{ WHIT.."23) "..AL["Elder Primestone"]	..DASH..BZ["The Crystal Vale"]..", "..BZ["Silithus"] };
		{ WHIT.."24) "..AL["Grimtotem Elder"]	..DASH..BZ["Lariss Pavilion"]..", "..BZ["Feralas"] };
		{ WHIT.."25) "..AL["Elder Mistwalker"]	..DASH..BZ["The Maul"]..", "..BZ["Broken Commons"]..", "..BZ["Dire Maul"]..", "..BZ["Feralas"] };
		{ WHIT.."26) "..AL["Elder Splitrock"]	..DASH..ORNG..BZ["Maraudon"]..", "..BZ["Desolace"] };
	};
};


Atlas_RegisterPlugin("Atlas_WorldEvents", myCategory, myData);
